Django GeoIP
============

.. image:: https://secure.travis-ci.org/futurecolors/django-geoip.png?branch=dev

App to figure out where your visitors are from by their IP address.

Detects country, region and city, querying the database with geodata.
Optional high-level API provides user location in request object.

Docs: http://django-geoip.readthedocs.org/